==> mars-1.1.1.tar.gz: mars-1.1.1/tests/TFP/TFP_4E_006/mpu1.c <==
/*
 * Copyright 2008 Sony Corporation
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

#include <mars/task.h>
#include <mars_task_test.h>
#include <spu_mfcio.h>

struct queue_entry {
	uint64_t val;
	uint64_t pad;
};
static struct queue_entry data;
static uint32_t shared_resource __attribute((aligned(16)));

int mars_task_main(const struct mars_task_args *task_args)
{
	int ret;
	uint64_t mpu_to_mpu_ea = task_args->type.u64[0];
	uint64_t shared_resource_ea = task_args->type.u64[1];
	uint64_t val = task_args->type.u64[2];

	while (1) {
		ret = mars_task_queue_try_pop_begin(mpu_to_mpu_ea, &data, 1);
		if (ret == MARS_SUCCESS)
			break;
		else if (ret == MARS_ERROR_BUSY)
			continue;
		else
			MARS_TEST_ASSERT_ERROR(ret, 0);
	}
	ret = mars_task_queue_pop_end(mpu_to_mpu_ea, 1);
	MARS_TEST_ASSERT_ERROR(ret, MARS_SUCCESS);

	MARS_TEST_ASSERT_EQUAL(data.val, val);

	/* if the program reaches here, shared_resource'll be updated */
	shared_resource = 1;
	mfc_put(&shared_resource, shared_resource_ea,
		sizeof(uint32_t), 0, 0, 0);
	mfc_write_tag_mask(1 << 0);
	mfc_read_tag_status_all();

	return 0;
}

==> mars-1.1.5.tar.gz: mars-1.1.5/tests/TFP/TFP_4E_006/mpu1.c <==
/*
 * Copyright 2008 Sony Corporation
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

#include <mars/task.h>
#include <mars_task_test.h>

struct queue_entry {
	uint64_t val;
	uint64_t pad;
};
static struct queue_entry data;

int mars_task_main(const struct mars_task_args *task_args)
{
	int ret;
	uint64_t mpu_to_mpu_ea = task_args->type.u64[0];
	uint64_t notify = task_args->type.u64[1];
	uint64_t val = task_args->type.u64[2];


	mars_test_counter_add(notify, 1);
	ret = mars_task_queue_pop_begin(mpu_to_mpu_ea, &data, 1);
	MARS_TEST_ASSERT_ERROR(ret, MARS_SUCCESS);

	mars_test_counter_add(notify, 1);
	ret = mars_task_queue_pop_end(mpu_to_mpu_ea, 1);

	MARS_TEST_ASSERT_ERROR(ret, MARS_SUCCESS);

	MARS_TEST_ASSERT_EQUAL(data.val, val);
	return 0;
}
